@@ -63,7 +63,7 @@ __author_email__ = author_email
 __contributors__ = contributors
 __license__ = 'MIT License'
 __copyright__ = r"""
-Copyright (c) 2020 Jason Dsouza <jasmcaus>
+Copyright (c) 2020-2021 Jason Dsouza <jasmcaus>
 All Rights Reserved.
 """
 __homepage__ = homepage
@@ -115,31 +115,57 @@ from .core import (
 
 # Color Spaces
 from .color import (
-    bgr_to_gray,
-    bgr_to_hsv,
-    bgr_to_lab,
-    bgr_to_rgb,
-    rgb_to_gray,
-    rgb_to_hsv,
-    rgb_to_lab,
-    rgb_to_bgr,
-    hsv_to_bgr,
-    hsv_to_gray,
-    hsv_to_lab,
-    hsv_to_rgb,
-    lab_to_bgr,
-    lab_to_gray,
-    lab_to_hsv,
-    lab_to_rgb,
-    is_rgb_image,
-    is_bgr_image,
-    is_hsv_image,
-    is_lab_image,
+    to_bgr,
+    to_rgb,
+    to_gray,
+    to_hsv,
+    to_hls,
+    to_lab,
+
+    bgr2rgb,
+    bgr2gray,
+    bgr2hsv,    
+    bgr2hls,
+    bgr2lab,
+
+    rgb2bgr,
+    rgb2gray,
+    rgb2hsv,
+    rgb2hls,
+    rgb2lab,
+
+    gray2rgb,
+    gray2bgr,    
+    gray2hsv,
+    gray2hls,
+    gray2lab,    
+
+    hsv2rgb,
+    hsv2bgr,
+    hsv2gray,
+    hsv2hls,
+    hsv2lab,
+
+    hls2rgb,
+    hls2bgr,
+    hls2gray,
+    hls2hsv,
+    hls2lab,
+
+    lab2rgb,
+    lab2bgr,
+    lab2gray,
+    lab2hsv,
+    lab2hls,
+
     __all__ as __all_color__
 )
 
+
 # Bringing in configuration variables from globals.py
-from .globals import *
+# from .globals import *
+
+# Tensor-stuff 
 from .adorad import *
 
 
@@ -158,7 +184,7 @@ def get_caer_methods():
 # __all__ configs
 from .globals import __all__ as __all_globals__
 
-from .augment import __all__ as __all_augment__
+from .transforms import __all__ as __all_transforms__
 from .data import __all__ as __all_data__
 # from .filters import __all__ as __all_filters__
 from .path import __all__ as __all_path__
@@ -168,7 +194,7 @@ from .video import __all__ as __all_video__
 
 __all__ = __all_globals__ + __all_core__ + __all_preprocess__
 
-__all__ += __all_augment__
+__all__ += __all_transforms__
 __all__ += __all_color__
 __all__ += __all_data__ 
 # __all__ += __all_filters__ 
@@ -191,7 +217,7 @@ del __all_globals__
 del __all_core__ 
 del __all_preprocess__ 
 
-del __all_augment__ 
+del __all_transforms__ 
 del __all_color__ 
 del __all_data__ 
 # del __all_filters__
