@@ -7,11 +7,15 @@
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
+# Copyright (c) 2020-21 The Caer Authors <http://github.com/jasmcaus>
 
 
 from .tensor import (
     Tensor,
-    from_numpy,
     is_tensor
+)
+
+from ._internal import (
+    from_numpy,
+    to_tensor
 )
\ No newline at end of file
